==> A.powerpc-ibm-aix4.1.5.0.tar.gz: A.powerpc-ibm-aix4.1.5.0/dbgcf.h <==

#define HOST_CPU "powerpc"
#define HOST_VENDOR "ibm"
#define HOST_OS "aix4.1.5.0"
#define HOST_OS_NAME "aix4"
#define HOST_OS_VERSION "4.1.5.0"
#define HOST_ARCH "003105F24C00"
#define HOST_NAME "anasazi"
#define USER_NAME "ezk"
#define CONFIG_DATE "Tue Jul  4 16:31:47 EDT 2000"
#define PACKAGE "am-utils"
#define VERSION "6.0.4s6"
#define PACKAGE "am-utils"
#define VERSION "6.0.4s6"
#define DEBUG 1
#define _ALL_SOURCE 1
#define HOST_HEADER_VERSION "4.1.5.0"
#define HAVE_LIBRPCSVC 1
#define HAVE_ALLOCA 1
#define STDC_HEADERS 1
#define vfork fork
#define HAVE_WAIT3 1
#define HAVE__SETERR_REPLY 1
#define HAVE_BCMP 1
#define HAVE_BCOPY 1
#define HAVE_BZERO 1
#define HAVE_CLNT_CREATE 1
#define HAVE_CLNT_SPCREATEERROR 1
#define HAVE_GET_MYADDRESS 1
#define HAVE_GETCWD 1
#define HAVE_GETDOMAINNAME 1
#define HAVE_GETDTABLESIZE 1
#define HAVE_GETHOSTNAME 1
#define HAVE_GETPAGESIZE 1
#define HAVE_GETTIMEOFDAY 1
#define HAVE_MEMCMP 1
#define HAVE_MEMCPY 1
#define HAVE_MEMMOVE 1
#define HAVE_MEMSET 1
#define HAVE_MKDIR 1
#define HAVE_MKSTEMP 1
#define HAVE_MNTCTL 1
#define HAVE_MOUNT 1
#define HAVE_PLOCK 1
#define HAVE_REGCOMP 1
#define HAVE_REGEXEC 1
#define HAVE_RMDIR 1
#define HAVE_SELECT 1
#define HAVE_SETEUID 1
#define HAVE_SETITIMER 1
#define HAVE_SETSID 1
#define HAVE_SIGACTION 1
#define HAVE_SIGNAL 1
#define HAVE_SOCKET 1
#define HAVE_STRCHR 1
#define HAVE_STRCSPN 1
#define HAVE_STRCASECMP 1
#define HAVE_STRDUP 1
#define HAVE_STRERROR 1
#define HAVE_STRSPN 1
#define HAVE_STRSTR 1
#define HAVE_SVC_GETREQ 1
#define HAVE_SVC_GETREQSET 1
#define HAVE_SYSLOG 1
#define HAVE_UNAME 1
#define HAVE_UMOUNT 1
#define HAVE_UNMOUNT 1
#define HAVE_UVMOUNT 1
#define HAVE_VFORK 1
#define HAVE_VMOUNT 1
#define HAVE_VSNPRINTF 1
#define HAVE_WAIT3 1
#define HAVE_WAITPID 1
#define HAVE_CLNT_SPERRNO 1
#define HAVE_STRCASECMP 1
#define HAVE_STRDUP 1
#define HAVE_STRSTR 1
#define HAVE_UALARM 1
#define HAVE_XDR_EXPORTS 1
#define HAVE_XDR_FHANDLE 1
#define HAVE_XDR_FHSTATUS 1
#define HAVE_XDR_GROUPS 1
#define HAVE_XDR_MOUNTBODY 1
#define HAVE_XDR_MOUNTLIST 1
#define HAVE_XDR_POINTER 1
#define HAVE_DIRENT_H 1
#define STDC_HEADERS 1
#define HAVE_SYS_WAIT_H 1
#define HAVE_ARPA_NAMESER_H 1
#define HAVE_ARPA_INET_H 1
#define HAVE_NET_IF_H 1
#define HAVE_NET_ROUTE_H 1
#define HAVE_NETINET_IF_ETHER_H 1
#define HAVE_NETINET_IN_H 1
#define HAVE_NFS_EXPORT_H 1
#define HAVE_NFS_NFS_H 1
#define HAVE_NFS_NFS_CLNT_H 1
#define HAVE_RPC_AUTH_DES_H 1
#define HAVE_RPC_PMAP_CLNT_H 1
#define HAVE_RPC_PMAP_PROT_H 1
#define HAVE_RPC_RPC_H 1
#define HAVE_RPC_TYPES_H 1
#define HAVE_RPC_XDR_H 1
#define HAVE_RPCSVC_MOUNT_H 1
#define HAVE_RPCSVC_NFS_PROT_H 1
#define HAVE_RPCSVC_YP_PROT_H 1
#define HAVE_RPCSVC_YPCLNT_H 1
#define HAVE_SYS_DIR_H 1
#define HAVE_SYS_ERRNO_H 1
#define HAVE_SYS_FILE_H 1
#define HAVE_SYS_IOCTL_H 1
#define HAVE_SYS_LOCK_H 1
#define HAVE_SYS_MACHINE_H 1
#define HAVE_SYS_MBUF_H 1
#define HAVE_SYS_MNTCTL_H 1
#define HAVE_SYS_PARAM_H 1
#define HAVE_SYS_PROC_H 1
#define HAVE_SYS_RESOURCE_H 1
#define HAVE_SYS_SIGNAL_H 1
#define HAVE_SYS_SOCKET_H 1
#define HAVE_SYS_STAT_H 1
#define HAVE_SYS_STATFS_H 1
#define HAVE_SYS_SYSLOG_H 1
#define HAVE_SYS_TIME_H 1
#define HAVE_SYS_TIUSER_H 1
#define HAVE_SYS_TYPES_H 1
#define HAVE_SYS_UIO_H 1
#define HAVE_SYS_UTSNAME_H 1
#define HAVE_SYS_VFS_H 1
#define HAVE_SYS_VMOUNT_H 1
#define HAVE_SYS_VNODE_H 1
#define HAVE_ASSERT_H 1
#define HAVE_CTYPE_H 1
#define HAVE_ERRNO_H 1
#define HAVE_FCNTL_H 1
#define HAVE_GRP_H 1
#define HAVE_LIBGEN_H 1
#define HAVE_MALLOC_H 1
#define HAVE_MEMORY_H 1
#define HAVE_NDBM_H 1
#define HAVE_NETDB_H 1
#define HAVE_PWD_H 1
#define HAVE_REGEX_H 1
#define HAVE_RESOLV_H 1
#define HAVE_SETJMP_H 1
#define HAVE_SIGNAL_H 1
#define HAVE_STDARG_H 1
#define HAVE_STDLIB_H 1
#define HAVE_STDIO_H 1
#define HAVE_STRING_H 1
#define HAVE_STRINGS_H 1
#define HAVE_SYSLOG_H 1
#define HAVE_TIME_H 1
#define HAVE_TIUSER_H 1
#define HAVE_VARARGS_H 1
#define HAVE_UNISTD_H 1
#define TIME_WITH_SYS_TIME 1
#define AMU_NFS_PROTOCOL_HEADER "../conf/nfs_prot/nfs_prot_aix4.h"
#define HAVE_STRUCT_NFS_ARGS 1
#define nfs_args_t struct nfs_args
#define NFS_FH_FIELD fh
#define am_nfs_fh nfs_fh
#define GETGROUPS_T gid_t
#define RETSIGTYPE void
#define MTYPE_TYPE int
#define MTYPE_PRINTF_TYPE "%d"
#define YP_ORDER_OUTORDER_TYPE int
#define RECVFROM_FROMLEN_TYPE size_t
#define AUTH_CREATE_GIDLIST_TYPE int
#define SVC_IN_ARG_TYPE caddr_t
#define XDRPROC_T_TYPE xdrproc_t
#define WORDS_BIGENDIAN 1
#define voidp void *
#define HAVE_EXTERN_OPTARG 1
#define HAVE_EXTERN_CLNT_SPCREATEERROR 1
#define HAVE_EXTERN_CLNT_SPERRNO 1
#define HAVE_EXTERN_FREE 1
#define HAVE_EXTERN_GETDTABLESIZE 1
#define HAVE_EXTERN_GETHOSTNAME 1
#define HAVE_EXTERN_GETLOGIN 1
#define HAVE_EXTERN_GETPAGESIZE 1
#define HAVE_EXTERN_GETWD 1
#define HAVE_EXTERN_MKSTEMP 1
#define HAVE_EXTERN_SBRK 1
#define HAVE_EXTERN_STRCASECMP 1
#define HAVE_EXTERN_STRDUP 1
#define HAVE_EXTERN_STRSTR 1
#define HAVE_EXTERN_UALARM 1
#define HAVE_EXTERN_USLEEP 1
#define HAVE_EXTERN_WAIT3 1
#define HAVE_LONG_FILE_NAMES 1
#define HAVE_FIELD_STRUCT_FHSTATUS_FHS_FH 1
#define HAVE_FIELD_NFS_ARGS_T_ACDIRMIN 1
#define HAVE_FIELD_NFS_ARGS_T_ACREGMIN 1
#define HAVE_FIELD_STRUCT_IFREQ_IFR_ADDR 1
#define HAVE_FIELD_STRUCT_SOCKADDR_SA_LEN 1
#define HAVE_MAP_FILE 1
#define HAVE_MAP_NDBM 1
#define HAVE_MAP_NIS 1
#define HAVE_MAP_PASSWD 1
#define HAVE_MAP_UNION 1
#define HAVE_FS_CDFS 1
#define HAVE_FS_NFS 1
#define HAVE_FS_UFS 1
#define HAVE_AMU_FS_AUTO 1
#define HAVE_AMU_FS_DIRECT 1
#define HAVE_AMU_FS_TOPLVL 1
#define HAVE_AMU_FS_ERROR 1
#define HAVE_AMU_FS_INHERIT 1
#define HAVE_AMU_FS_PROGRAM 1
#define HAVE_AMU_FS_LINK 1
#define HAVE_AMU_FS_LINKX 1
#define HAVE_AMU_FS_HOST 1
#define HAVE_AMU_FS_NFSX 1
#define HAVE_AMU_FS_NFSL 1
#define HAVE_AMU_FS_UNION 1
#define MOUNT_TYPE_NFS MNT_NFS
#define MOUNT_TYPE_UFS MNT_JFS
#define MOUNT_TYPE_CDFS MNT_CDROM
#define MNTTAB_TYPE_NFS "nfs"
#define MNTTAB_TYPE_UFS "ufs"
#define MNTTAB_TYPE_CDFS "cdfs"
#define MNTTAB_OPT_ACDIRMAX "acdirmax"
#define MNTTAB_OPT_ACDIRMIN "acdirmin"
#define MNTTAB_OPT_ACREGMAX "acregmax"
#define MNTTAB_OPT_ACREGMIN "acregmin"
#define MNTTAB_OPT_ACTIMEO "actimeo"
#define MNTTAB_OPT_GRPID "grpid"
#define MNTTAB_OPT_INTR "intr"
#define MNTTAB_OPT_NOAC "noac"
#define MNTTAB_OPT_NOAUTO "noauto"
#define MNTTAB_OPT_NOCTO "nocto"
#define MNTTAB_OPT_NOSUID "nosuid"
#define MNTTAB_OPT_PORT "port"
#define MNTTAB_OPT_POSIX "posix"
#define MNTTAB_OPT_RETRANS "retrans"
#define MNTTAB_OPT_RO "ro"
#define MNTTAB_OPT_RSIZE "rsize"
#define MNTTAB_OPT_RW "rw"
#define MNTTAB_OPT_SOFT "soft"
#define MNTTAB_OPT_TIMEO "timeo"
#define MNTTAB_OPT_WSIZE "wsize"
#define MNT2_GEN_OPT_NODEV 0x80
#define MNT2_GEN_OPT_NOSUID 0x40
#define MNT2_NFS_OPT_ACDIRMAX 0x800
#define MNT2_NFS_OPT_ACDIRMIN 0x400
#define MNT2_NFS_OPT_ACREGMAX 0x200
#define MNT2_NFS_OPT_ACREGMIN 0x100
#define MNT2_NFS_OPT_GRPID 0x40000
#define MNT2_NFS_OPT_HOSTNAME 0x20
#define MNT2_NFS_OPT_INT 0x40
#define MNT2_NFS_OPT_NOAC 0x80
#define MNT2_NFS_OPT_NOCTO 0x2000
#define MNT2_NFS_OPT_POSIX 0x4000
#define MNT2_NFS_OPT_RETRANS 0x10
#define MNT2_NFS_OPT_RSIZE 0x4
#define MNT2_NFS_OPT_SOFT 0x1
#define MNT2_NFS_OPT_TIMEO 0x8
#define MNT2_NFS_OPT_WSIZE 0x2
#define HIDE_MOUNT_TYPE "nfs"

==> A.powerpc-ibm-aix4.2.1.0.tar.gz: A.powerpc-ibm-aix4.2.1.0/dbgcf.h <==

#define HOST_CPU "powerpc"
#define HOST_VENDOR "ibm"
#define HOST_OS "aix4.2.1.0"
#define HOST_OS_NAME "aix4"
#define HOST_OS_VERSION "4.2.1.0"
#define HOST_ARCH "002025934C00"
#define HOST_NAME "quechua"
#define USER_NAME "ezk"
#define CONFIG_DATE "Tue Jul  4 17:06:01 EDT 2000"
#define PACKAGE "am-utils"
#define VERSION "6.0.4s6"
#define PACKAGE "am-utils"
#define VERSION "6.0.4s6"
#define DEBUG 1
#define _ALL_SOURCE 1
#define HOST_HEADER_VERSION "4.2.1.0"
#define HAVE_LIBRPCSVC 1
#define HAVE_ALLOCA 1
#define STDC_HEADERS 1
#define HAVE_WAIT3 1
#define HAVE__SETERR_REPLY 1
#define HAVE_BCMP 1
#define HAVE_BCOPY 1
#define HAVE_BZERO 1
#define HAVE_CLNT_CREATE 1
#define HAVE_CLNT_SPCREATEERROR 1
#define HAVE_GET_MYADDRESS 1
#define HAVE_GETCWD 1
#define HAVE_GETDOMAINNAME 1
#define HAVE_GETDTABLESIZE 1
#define HAVE_GETHOSTNAME 1
#define HAVE_GETPAGESIZE 1
#define HAVE_GETTIMEOFDAY 1
#define HAVE_MEMCMP 1
#define HAVE_MEMCPY 1
#define HAVE_MEMMOVE 1
#define HAVE_MEMSET 1
#define HAVE_MKDIR 1
#define HAVE_MKSTEMP 1
#define HAVE_MNTCTL 1
#define HAVE_MOUNT 1
#define HAVE_PLOCK 1
#define HAVE_REGCOMP 1
#define HAVE_REGEXEC 1
#define HAVE_RMDIR 1
#define HAVE_SELECT 1
#define HAVE_SETEUID 1
#define HAVE_SETITIMER 1
#define HAVE_SETSID 1
#define HAVE_SIGACTION 1
#define HAVE_SIGNAL 1
#define HAVE_SOCKET 1
#define HAVE_STRCHR 1
#define HAVE_STRCSPN 1
#define HAVE_STRCASECMP 1
#define HAVE_STRDUP 1
#define HAVE_STRERROR 1
#define HAVE_STRSPN 1
#define HAVE_STRSTR 1
#define HAVE_SVC_GETREQ 1
#define HAVE_SVC_GETREQSET 1
#define HAVE_SYSLOG 1
#define HAVE_UNAME 1
#define HAVE_UMOUNT 1
#define HAVE_UNMOUNT 1
#define HAVE_UVMOUNT 1
#define HAVE_VFORK 1
#define HAVE_VMOUNT 1
#define HAVE_VSNPRINTF 1
#define HAVE_WAIT3 1
#define HAVE_WAITPID 1
#define HAVE_CLNT_SPERRNO 1
#define HAVE_STRCASECMP 1
#define HAVE_STRDUP 1
#define HAVE_STRSTR 1
#define HAVE_UALARM 1
#define HAVE_XDR_EXPORTS 1
#define HAVE_XDR_FHANDLE 1
#define HAVE_XDR_FHSTATUS 1
#define HAVE_XDR_GROUPS 1
#define HAVE_XDR_MOUNTBODY 1
#define HAVE_XDR_MOUNTLIST 1
#define HAVE_XDR_POINTER 1
#define HAVE_DIRENT_H 1
#define STDC_HEADERS 1
#define HAVE_SYS_WAIT_H 1
#define HAVE_ARPA_NAMESER_H 1
#define HAVE_ARPA_INET_H 1
#define HAVE_NET_IF_H 1
#define HAVE_NET_ROUTE_H 1
#define HAVE_NETINET_IF_ETHER_H 1
#define HAVE_NETINET_IN_H 1
#define HAVE_NFS_EXPORT_H 1
#define HAVE_NFS_NFS_H 1
#define HAVE_NFS_NFS_CLNT_H 1
#define HAVE_RPC_AUTH_DES_H 1
#define HAVE_RPC_PMAP_CLNT_H 1
#define HAVE_RPC_PMAP_PROT_H 1
#define HAVE_RPC_RPC_H 1
#define HAVE_RPC_TYPES_H 1
#define HAVE_RPC_XDR_H 1
#define HAVE_RPCSVC_MOUNT_H 1
#define HAVE_RPCSVC_NFS_PROT_H 1
#define HAVE_RPCSVC_YP_PROT_H 1
#define HAVE_RPCSVC_YPCLNT_H 1
#define HAVE_SYS_DIR_H 1
#define HAVE_SYS_ERRNO_H 1
#define HAVE_SYS_FILE_H 1
#define HAVE_SYS_IOCTL_H 1
#define HAVE_SYS_LOCK_H 1
#define HAVE_SYS_MACHINE_H 1
#define HAVE_SYS_MBUF_H 1
#define HAVE_SYS_MNTCTL_H 1
#define HAVE_SYS_PARAM_H 1
#define HAVE_SYS_PROC_H 1
#define HAVE_SYS_RESOURCE_H 1
#define HAVE_SYS_SIGNAL_H 1
#define HAVE_SYS_SOCKET_H 1
#define HAVE_SYS_STAT_H 1
#define HAVE_SYS_STATFS_H 1
#define HAVE_SYS_SYSLOG_H 1
#define HAVE_SYS_TIME_H 1
#define HAVE_SYS_TIUSER_H 1
#define HAVE_SYS_TYPES_H 1
#define HAVE_SYS_UIO_H 1
#define HAVE_SYS_UTSNAME_H 1
#define HAVE_SYS_VFS_H 1
#define HAVE_SYS_VMOUNT_H 1
#define HAVE_SYS_VNODE_H 1
#define HAVE_ASSERT_H 1
#define HAVE_CTYPE_H 1
#define HAVE_ERRNO_H 1
#define HAVE_FCNTL_H 1
#define HAVE_GRP_H 1
#define HAVE_LIBGEN_H 1
#define HAVE_MALLOC_H 1
#define HAVE_MEMORY_H 1
#define HAVE_NDBM_H 1
#define HAVE_NETDB_H 1
#define HAVE_PWD_H 1
#define HAVE_REGEX_H 1
#define HAVE_RESOLV_H 1
#define HAVE_SETJMP_H 1
#define HAVE_SIGNAL_H 1
#define HAVE_STDARG_H 1
#define HAVE_STDLIB_H 1
#define HAVE_STDIO_H 1
#define HAVE_STRING_H 1
#define HAVE_STRINGS_H 1
#define HAVE_SYSLOG_H 1
#define HAVE_TIME_H 1
#define HAVE_TIUSER_H 1
#define HAVE_VARARGS_H 1
#define HAVE_UNISTD_H 1
#define TIME_WITH_SYS_TIME 1
#define AMU_NFS_PROTOCOL_HEADER "../conf/nfs_prot/nfs_prot_aix4_2.h"
#define HAVE_STRUCT_NFS_ARGS 1
#define nfs_args_t struct aix42_nfs_args
#define NFS_FH_FIELD fh
#define am_nfs_fh nfs_fh
#define am_nfs_fh3 nfs_fh3
#define GETGROUPS_T gid_t
#define RETSIGTYPE void
#define MTYPE_TYPE int
#define MTYPE_PRINTF_TYPE "%d"
#define YP_ORDER_OUTORDER_TYPE int
#define RECVFROM_FROMLEN_TYPE size_t
#define AUTH_CREATE_GIDLIST_TYPE int
#define SVC_IN_ARG_TYPE caddr_t
#define XDRPROC_T_TYPE xdrproc_t
#define WORDS_BIGENDIAN 1
#define voidp void *
#define HAVE_EXTERN_OPTARG 1
#define HAVE_EXTERN_CLNT_SPCREATEERROR 1
#define HAVE_EXTERN_CLNT_SPERRNO 1
#define HAVE_EXTERN_FREE 1
#define HAVE_EXTERN_GETDTABLESIZE 1
#define HAVE_EXTERN_GETHOSTNAME 1
#define HAVE_EXTERN_GETLOGIN 1
#define HAVE_EXTERN_GETPAGESIZE 1
#define HAVE_EXTERN_GETWD 1
#define HAVE_EXTERN_MKSTEMP 1
#define HAVE_EXTERN_SBRK 1
#define HAVE_EXTERN_SETITIMER 1
#define HAVE_EXTERN_STRCASECMP 1
#define HAVE_EXTERN_STRDUP 1
#define HAVE_EXTERN_STRSTR 1
#define HAVE_EXTERN_UALARM 1
#define HAVE_EXTERN_USLEEP 1
#define HAVE_EXTERN_WAIT3 1
#define HAVE_LONG_FILE_NAMES 1
#define HAVE_FIELD_STRUCT_FHSTATUS_FHS_FH 1
#define HAVE_FIELD_NFS_ARGS_T_ACDIRMIN 1
#define HAVE_FIELD_NFS_ARGS_T_ACREGMIN 1
#define HAVE_FIELD_NFS_ARGS_T_PROTO 1
#define HAVE_FIELD_STRUCT_IFREQ_IFR_ADDR 1
#define HAVE_FIELD_STRUCT_SOCKADDR_SA_LEN 1
#define HAVE_MAP_FILE 1
#define HAVE_MAP_NDBM 1
#define HAVE_MAP_NIS 1
#define HAVE_MAP_PASSWD 1
#define HAVE_MAP_UNION 1
#define HAVE_FS_CDFS 1
#define HAVE_FS_NFS 1
#define HAVE_FS_NFS3 1
#define HAVE_FS_UFS 1
#define HAVE_AMU_FS_AUTO 1
#define HAVE_AMU_FS_DIRECT 1
#define HAVE_AMU_FS_TOPLVL 1
#define HAVE_AMU_FS_ERROR 1
#define HAVE_AMU_FS_INHERIT 1
#define HAVE_AMU_FS_PROGRAM 1
#define HAVE_AMU_FS_LINK 1
#define HAVE_AMU_FS_LINKX 1
#define HAVE_AMU_FS_HOST 1
#define HAVE_AMU_FS_NFSX 1
#define HAVE_AMU_FS_NFSL 1
#define HAVE_AMU_FS_UNION 1
#define MOUNT_TYPE_NFS MNT_NFS
#define MOUNT_TYPE_NFS3 MNT_NFS3
#define MOUNT_TYPE_UFS MNT_JFS
#define MOUNT_TYPE_CDFS MNT_CDROM
#define MNTTAB_TYPE_NFS "nfs"
#define MNTTAB_TYPE_NFS3 "nfs3"
#define MNTTAB_TYPE_UFS "ufs"
#define MNTTAB_TYPE_CDFS "cdfs"
#define MNTTAB_OPT_ACDIRMAX "acdirmax"
#define MNTTAB_OPT_ACDIRMIN "acdirmin"
#define MNTTAB_OPT_ACREGMAX "acregmax"
#define MNTTAB_OPT_ACREGMIN "acregmin"
#define MNTTAB_OPT_ACTIMEO "actimeo"
#define MNTTAB_OPT_GRPID "grpid"
#define MNTTAB_OPT_INTR "intr"
#define MNTTAB_OPT_NOAC "noac"
#define MNTTAB_OPT_NOAUTO "noauto"
#define MNTTAB_OPT_NOCTO "nocto"
#define MNTTAB_OPT_NOSUID "nosuid"
#define MNTTAB_OPT_PORT "port"
#define MNTTAB_OPT_POSIX "posix"
#define MNTTAB_OPT_RETRANS "retrans"
#define MNTTAB_OPT_RO "ro"
#define MNTTAB_OPT_RSIZE "rsize"
#define MNTTAB_OPT_RW "rw"
#define MNTTAB_OPT_SOFT "soft"
#define MNTTAB_OPT_TIMEO "timeo"
#define MNTTAB_OPT_WSIZE "wsize"
#define MNT2_GEN_OPT_NODEV 0x80
#define MNT2_GEN_OPT_NOSUID 0x40
#define MNT2_NFS_OPT_ACDIRMAX 0x800
#define MNT2_NFS_OPT_ACDIRMIN 0x400
#define MNT2_NFS_OPT_ACREGMAX 0x200
#define MNT2_NFS_OPT_ACREGMIN 0x100
#define MNT2_NFS_OPT_GRPID 0x40000
#define MNT2_NFS_OPT_HOSTNAME 0x20
#define MNT2_NFS_OPT_INT 0x40
#define MNT2_NFS_OPT_NOAC 0x80
#define MNT2_NFS_OPT_NOCTO 0x2000
#define MNT2_NFS_OPT_POSIX 0x4000
#define MNT2_NFS_OPT_RETRANS 0x10
#define MNT2_NFS_OPT_RSIZE 0x4
#define MNT2_NFS_OPT_SOFT 0x1
#define MNT2_NFS_OPT_TIMEO 0x8
#define MNT2_NFS_OPT_WSIZE 0x2
#define HIDE_MOUNT_TYPE "nfs"
